<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX Oprava zavaděče</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="45"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>MX Boot Repair je nástroj, který lze použít k opětovné instalaci bootloaderu GRUB na ESP (EFI System Partition), MBR (Master Boot Record) nebo kořenový oddíl. Poskytuje možnost rekonstrukce konfiguračního souboru GRUB, zálohování a obnovení MBR nebo PBR (root).</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="64"/>
        <source>What would you like to do?</source>
        <translation>Co si přejete provést?</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="94"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Záloha MBR a PBR (pouze pro legacy boot)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="70"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Přeinstalovat zavaděč GRUB na ESP, MBR nebo PBR (root)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="80"/>
        <source>Repair GRUB configuration file</source>
        <translation>Opravit konfigurační soubor GRUB-u</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="87"/>
        <source>Regenerate initramfs images</source>
        <translation>Regenerovat obrazy initramfs</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="101"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Obnovit MBR nebo PBR ze zálohy (pouze pro legacy boot)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="134"/>
        <location filename="../src/gui/mainwindow.cpp" line="425"/>
        <source>Select Boot Method</source>
        <translation>Vyberte způsob zavedení</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="152"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="155"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="158"/>
        <location filename="../src/gui/mainwindow.ui" line="398"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="193"/>
        <location filename="../src/gui/mainwindow.cpp" line="426"/>
        <source>Location:</source>
        <translation>Umístnění:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="218"/>
        <source>EFI System Partition</source>
        <translation>Oddíl systému EFI</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="221"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="240"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root (Partition Boot Record)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="243"/>
        <location filename="../src/gui/mainwindow.cpp" line="428"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="278"/>
        <location filename="../src/gui/mainwindow.cpp" line="433"/>
        <source>Select root location:</source>
        <translation>Vyberte kořenové umístění:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="300"/>
        <location filename="../src/gui/mainwindow.cpp" line="427"/>
        <source>Install on:</source>
        <translation>Instalovat na:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="389"/>
        <source>About this application</source>
        <translation>O této aplikaci</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="392"/>
        <source>About...</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="440"/>
        <source>Display help </source>
        <translation>Zobrazit nápovědu</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="443"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="449"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="490"/>
        <source>Cancel any changes then quit</source>
        <translation>Zrušit všechny změny a ukončit</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="493"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="499"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="518"/>
        <source>Apply any changes</source>
        <translation>Uložit všechny změny</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="521"/>
        <location filename="../src/gui/mainwindow.cpp" line="82"/>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="461"/>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="102"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB se instaluje na zařízení %1.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="292"/>
        <location filename="../src/gui/mainwindow.cpp" line="350"/>
        <location filename="../src/gui/mainwindow.cpp" line="466"/>
        <location filename="../src/gui/mainwindow.cpp" line="470"/>
        <location filename="../src/gui/mainwindow.cpp" line="477"/>
        <location filename="../src/gui/mainwindow.cpp" line="483"/>
        <location filename="../src/gui/mainwindow.cpp" line="491"/>
        <location filename="../src/gui/mainwindow.cpp" line="498"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="142"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>Konfigurační soubor GRUB (grub.cfg) se znovu sestavuje.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="176"/>
        <source>Generating initramfs images on: %1</source>
        <translation>Generování obrazů initramfs na: %1</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="205"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Zálohování MBR nebo PBR ze zařízení %1.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="261"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="262"/>
        <source>You are going to write the content of </source>
        <translation>Chystáte se zapsat obsah</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="262"/>
        <source> to </source>
        <translation>do</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="263"/>
        <source>

Are you sure?</source>
        <translation>

Jste si jistí?</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="269"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Obnova MBR/PBR ze zálohy na zařízení %1.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="293"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Nelze najít EFI oddíl (ESP) na systémových discích. Prosím vytvořte ESP a zkuste to znovu.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="305"/>
        <source>Select %1 location:</source>
        <translation>Vybrat umístění %1:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="328"/>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="344"/>
        <source>Success</source>
        <translation>Úspěch!</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="344"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Proces byl úspěšně dokončen.&lt;p&gt;&lt;b&gt;Přejete si ukončit program MX Oprava zavaděče?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="350"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Proces dokončen. Vyskytly se chyby. </translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="109"/>
        <location filename="../src/gui/mainwindow.cpp" line="150"/>
        <location filename="../src/gui/mainwindow.cpp" line="182"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Zapsat heslo pro odemčení šifrovaného oddílu %1:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="432"/>
        <source>Select GRUB location</source>
        <translation>Vyberte umístění GRUB</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="441"/>
        <source>Select initramfs options</source>
        <translation>Vyberte možnosti initramfs</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="451"/>
        <source>Select Item to Back Up</source>
        <translation>Vyberte položku k záloze</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="456"/>
        <source>Select Item to Restore</source>
        <translation>Vyberte položku k obnově</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="466"/>
        <location filename="../src/gui/mainwindow.cpp" line="477"/>
        <source>No location was selected.</source>
        <translation>Nebylo vybráno žádné místo.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="471"/>
        <location filename="../src/gui/mainwindow.cpp" line="484"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Vyberte kořenový oddíl systému, který chcete opravit.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="489"/>
        <source>Select backup file name</source>
        <translation>Vyberte název souboru zálohy</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="491"/>
        <location filename="../src/gui/mainwindow.cpp" line="498"/>
        <source>No file was selected.</source>
        <translation>Nebyl vybrán žádný soubor</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="496"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Vyberte soubor MBR nebo PBR zálohy</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="514"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="516"/>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="517"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Jednoduchá oprava zavaděče pro MX Linux</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="519"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Vlastnická práva (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="520"/>
        <source>%1 License</source>
        <translation>Licence %1</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="533"/>
        <source>%1 Help</source>
        <translation>Nápověda %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/gui/about.cpp" line="52"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="53"/>
        <location filename="../src/gui/about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Protokol změn</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="86"/>
        <source>MX Boot Repair</source>
        <translation>MX Oprava zavaděče</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="94"/>
        <source>MX Boot Repair - GUI and CLI tool for repairing GRUB bootloader</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="99"/>
        <source>Force CLI mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="100"/>
        <source>Print actions without executing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="101"/>
        <source>Do not prompt; require flags</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="102"/>
        <source>Action: install, repair, initramfs, backup, restore</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="103"/>
        <source>Target for install: mbr, esp, root</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="104"/>
        <source>Device for target (e.g., sda, sda1)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="105"/>
        <source>Root partition (e.g., /dev/sda2)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="106"/>
        <source>Partition to mount at /boot in chroot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="107"/>
        <source>Partition to mount at /boot/efi in chroot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="108"/>
        <source>Path for backup/restore image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="109"/>
        <source>Skip confirmations (for restore)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="110"/>
        <source>Enable verbose output</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="111"/>
        <source>Suppress non-error output</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="121"/>
        <source>Error: --verbose and --quiet options are mutually exclusive
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="127"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="128"/>
        <source>You must run this program with admin access.</source>
        <translation>Tento program musíte spustit s oprávněním správce.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="29"/>
        <source>Invalid index. Try again: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="48"/>
        <source>Invalid selection. Enter a number </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="234"/>
        <source>MX Boot Repair (CLI)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="235"/>
        <source>1) Install GRUB</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="236"/>
        <source>2) Repair GRUB (update-grub)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="237"/>
        <source>3) Regenerate initramfs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="238"/>
        <source>4) Backup MBR/PBR</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="239"/>
        <source>5) Restore MBR/PBR</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="240"/>
        <source>q) Quit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="241"/>
        <source>Select action [1-5 or &apos;q&apos; to quit]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="247"/>
        <source>Invalid selection. Enter 1-5 or &apos;q&apos; to quit.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="252"/>
        <source>Target: 0) MBR  1) ESP  2) Root</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="253"/>
        <source>Select target</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="259"/>
        <location filename="../src/cli/controller.cpp" line="297"/>
        <location filename="../src/cli/controller.cpp" line="310"/>
        <source>No partitions found. Returning to main menu.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="263"/>
        <location filename="../src/cli/controller.cpp" line="323"/>
        <location filename="../src/cli/controller.cpp" line="341"/>
        <source>No disks found. Returning to main menu.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="268"/>
        <source>Select disk for MBR (e.g., sda)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="272"/>
        <source>Select partition for GRUB (e.g., sda1)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="277"/>
        <source>Select root partition of installed system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="298"/>
        <source>Select root partition to repair</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="311"/>
        <source>Select root partition to regenerate initramfs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="324"/>
        <source>Select disk to back up MBR/PBR from</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="327"/>
        <source>Output file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="342"/>
        <source>Select disk to restore MBR/PBR to</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="345"/>
        <source>Input backup file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="352"/>
        <source>WARNING: This will overwrite the first 446 bytes of /dev/</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="352"/>
        <source>. Continue? [y/N]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="355"/>
        <source>yes</source>
        <comment>confirmation input: full word</comment>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="356"/>
        <source>y</source>
        <comment>confirmation input: single-letter yes</comment>
        <translation>a</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="360"/>
        <source>Cancelled.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="367"/>
        <source>Unknown selection</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>